@@ -2,8 +2,8 @@
                           dcopiface_shell.cpp  -  description
                              -------------------
     begin                : Tue Oct 23 2001
-    copyright            : (C) 2001 by The KXMLEditor Team
-    email                : lvanek@eanet.cz
+    copyright            : (C) 2001, 2002, 2003 by The KXMLEditor Team
+    email                : lvanek@users.sourceforge.net
  ***************************************************************************/
 
 /***************************************************************************
