@@ -22,8 +22,8 @@
 ///////////		Cutting element to clipboard			//////////
 //////////////////////////////////////////////////////////////////////////////////////////
 
-KXECutCommand::KXECutCommand(KXMLEditorPart *pPart, QDomNode &domNode)
- : KXEDeleteNodeCommand(pPart, domNode)
+KXECutCommand::KXECutCommand(KXEDocument *pDocument, QDomNode &domNode)
+ : KXEDeleteNodeCommand(pDocument, domNode)
 {
 }
 
@@ -36,11 +36,11 @@ KXECutCommand::~KXECutCommand()
 //////////////////////////////////////////////////////////////////////////////////////////
 
 KXEPasteToDocumentCommand::KXEPasteToDocumentCommand(
-  KXMLEditorPart *pPart,
+  KXEDocument *pDocument,
   QDomDocument *pDomTargetDoc,
   QDomElement &domSourceElement
   )
- : KXECommand(pPart)
+ : KXECommand(pDocument)
 {
   if ( pDomTargetDoc == 0 )
     kdError() << "KXEPasteToDocumentCommand::KXEPasteToDocumentCommand the given XML document object is empty." << endl;
@@ -58,7 +58,7 @@ void KXEPasteToDocumentCommand::execute()
   // Insert root element
   QDomNode newNode = m_pDomTargetDoc->importNode(m_domSourceElement, true);
   m_pDomTargetDoc->appendChild(newNode);
-  m_pPart->updateNodeCreated(newNode);
+  m_pDocument->updateNodeCreated(newNode);
 }
 
 void KXEPasteToDocumentCommand::unexecute()
@@ -69,7 +69,7 @@ void KXEPasteToDocumentCommand::unexecute()
 		kdError() << "KXEPasteToDocumentCommand::unexecute error removing node." << endl;
 	else
 	{
-		m_pPart->updateNodeDeleted(removedNode);
+		m_pDocument->updateNodeDeleted(removedNode);
   }
 }
 
@@ -78,11 +78,11 @@ void KXEPasteToDocumentCommand::unexecute()
 //////////////////////////////////////////////////////////////////////////////////////////
 
 KXEPasteToElementCommand::KXEPasteToElementCommand(
-  KXMLEditorPart *pPart,
+  KXEDocument *pDocument,
   QDomElement & domTargetElement,
   QDomNode &domSourceNode
   )
- : KXECommand(pPart)
+ : KXECommand(pDocument)
 {
   if ( domTargetElement.isNull() )
     kdError() << "KXEPasteCommand::KXEPasteCommand the given XML element object is empty." << endl;
@@ -98,7 +98,7 @@ KXEPasteToElementCommand::~KXEPasteToElementCommand()
 void KXEPasteToElementCommand::execute()
 {
   m_domTargetElement.appendChild(m_domSourceNode);
- 	m_pPart->updateNodeCreated(m_domSourceNode);
+ 	m_pDocument->updateNodeCreated(m_domSourceNode);
 }
 
 void KXEPasteToElementCommand::unexecute()
@@ -107,7 +107,7 @@ void KXEPasteToElementCommand::unexecute()
 		kdError() << "KXEPasteToElementCommand::unexecute error removing the node." << endl;
 	else
 	{
-		m_pPart->updateNodeDeleted(m_domSourceNode);
+		m_pDocument->updateNodeDeleted(m_domSourceNode);
   }
 }
 
@@ -116,11 +116,11 @@ void KXEPasteToElementCommand::unexecute()
 //////////////////////////////////////////////////////////////////////////////////////////
 
 KXEPasteToProcInstrCommand::KXEPasteToProcInstrCommand(
-  KXMLEditorPart *pPart,
+  KXEDocument *pDocument,
   QDomProcessingInstruction &domTargetProcInstr,
   QDomProcessingInstruction &domSourceProcInstr
   )
- : KXECommand(pPart)
+ : KXECommand(pDocument)
 {
   if ( domTargetProcInstr.isNull() )
     kdError() << "KXEPasteToProcInstrCommand::KXEPasteToProcInstrCommand the given object is empty." << endl;
@@ -141,14 +141,14 @@ void KXEPasteToProcInstrCommand::execute()
   // Replace contents of selected proc. instr.
   m_strOldData = m_domTargetProcInstr.data();
  	m_domTargetProcInstr.setData(m_strNewData);    
-  m_pPart->updateNodeChanged(m_domTargetProcInstr);
+  m_pDocument->updateNodeChanged(m_domTargetProcInstr);
 }
 
 void KXEPasteToProcInstrCommand::unexecute()
 {
   // Rverse action.
  	m_domTargetProcInstr.setData(m_strOldData);
-  m_pPart->updateNodeChanged(m_domTargetProcInstr);
+  m_pDocument->updateNodeChanged(m_domTargetProcInstr);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////
@@ -157,11 +157,11 @@ void KXEPasteToProcInstrCommand::unexecute()
 
 
 KXEPasteToCharDataCommand::KXEPasteToCharDataCommand(
-  KXMLEditorPart *pPart,
+  KXEDocument *pDocument,
   QDomCharacterData &domTargetCharData,
   QDomCharacterData &domSourceCharData
   )
- : KXECommand(pPart)
+ : KXECommand(pDocument)
 {
   if ( domTargetCharData.isNull() )
     kdError() << "KXEPasteToCharDataCommand::KXEPasteToCharDataCommand the given object is empty." << endl;
@@ -182,13 +182,13 @@ void KXEPasteToCharDataCommand::execute()
   // replace target contents with source
   m_strOldData = m_domTargetCharData.data();
   m_domTargetCharData.setData(m_strNewData);
- 	m_pPart->updateNodeChanged(m_domTargetCharData);
+ 	m_pDocument->updateNodeChanged(m_domTargetCharData);
 }
 
 void KXEPasteToCharDataCommand::unexecute()
 {
   m_domTargetCharData.setData(m_strOldData);
- 	m_pPart->updateNodeChanged(m_domTargetCharData);
+ 	m_pDocument->updateNodeChanged(m_domTargetCharData);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////
@@ -196,11 +196,11 @@ void KXEPasteToCharDataCommand::unexecute()
 //////////////////////////////////////////////////////////////////////////////////////////
 
 KXEDragDropMoveCommand::KXEDragDropMoveCommand(
-  KXMLEditorPart *pPart,
+  KXEDocument *pDocument,
   QDomElement & domTargetElement,
   QDomNode &domSourceNode
   )
- : KXECommand(pPart)
+ : KXECommand(pDocument)
 {
   if ( domTargetElement.isNull() )
     kdError() << "KXEDragDropMoveCommand::KXEDragDropMoveCommand the given XML element object is empty." << endl;
@@ -218,13 +218,13 @@ void KXEDragDropMoveCommand::execute()
 {
   // 1st, remove source node from its parent
   if( m_domPreviousParentNode.removeChild( m_domSourceNode ).isNull() )
-      kdError() << "KXMLEditorPart::slotXmlElementDelete error removing the selected node." << endl;
+      kdError() << "KXEDocument::slotXmlElementDelete error removing the selected node." << endl;
   else
-      m_pPart->updateNodeDeleted(m_domSourceNode);
+      m_pDocument->updateNodeDeleted(m_domSourceNode);
 
   // 2nd, append moved node to new parent
   m_domTargetElement.appendChild(m_domSourceNode);
- 	m_pPart->updateNodeCreated(m_domSourceNode);
+ 	m_pDocument->updateNodeCreated(m_domSourceNode);
 }
 
 void KXEDragDropMoveCommand::unexecute()
@@ -234,12 +234,12 @@ void KXEDragDropMoveCommand::unexecute()
 		kdError() << "KXEPasteToElementCommand::unexecute error removing the node." << endl;
 	else
 	{
-		m_pPart->updateNodeDeleted(m_domSourceNode);
+		m_pDocument->updateNodeDeleted(m_domSourceNode);
   }
 
   // 2nd, append moved node to previous parent
   m_domPreviousParentNode.appendChild(m_domSourceNode);
-  m_pPart->updateNodeCreated(m_domSourceNode);
+  m_pDocument->updateNodeCreated(m_domSourceNode);
 }
 
 
@@ -247,8 +247,8 @@ void KXEDragDropMoveCommand::unexecute()
 ///////////		Deleting node 					//////////
 //////////////////////////////////////////////////////////////////////////////////////////
 
-KXEDeleteNodeCommand::KXEDeleteNodeCommand(KXMLEditorPart *pPart, QDomNode &domNode)
- : KXECommand(pPart)
+KXEDeleteNodeCommand::KXEDeleteNodeCommand(KXEDocument *pDocument, QDomNode &domNode)
+ : KXECommand(pDocument)
 {
   m_domNode = domNode;
   m_domParentNode = m_domNode.parentNode();
@@ -268,7 +268,7 @@ void KXEDeleteNodeCommand::execute()
 		kdError() << "KXEDeleteNodeCommand::execute error removing the selected node." << endl;
 	else
 	{
-		m_pPart->updateNodeDeleted(m_domNode);
+		m_pDocument->updateNodeDeleted(m_domNode);
   }
 }
 
@@ -278,7 +278,7 @@ void KXEDeleteNodeCommand::unexecute()
 		m_domParentNode.insertBefore(m_domNode,m_afterNode);
 	else
   		m_domParentNode.insertAfter( m_domNode,m_afterNode );
-  	m_pPart->updateNodeCreated(m_domNode);
+  	m_pDocument->updateNodeCreated(m_domNode);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////
@@ -287,11 +287,11 @@ void KXEDeleteNodeCommand::unexecute()
 
 
 KXEDeleteAttrCommand::KXEDeleteAttrCommand(
-  KXMLEditorPart *pPart,
+  KXEDocument *pDocument,
   QDomElement &domOwnerElement,
   QDomAttr &domAttr
   )
- : KXECommand(pPart)
+ : KXECommand(pDocument)
 {
   m_domOwnerElement = domOwnerElement;
   m_domAttr = domAttr;
@@ -304,13 +304,13 @@ KXEDeleteAttrCommand::~KXEDeleteAttrCommand()
 void KXEDeleteAttrCommand::execute()
 {
   m_domOwnerElement.removeAttributeNode(m_domAttr);
-	m_pPart->updateNodeChanged(m_domOwnerElement);
+	m_pDocument->updateNodeChanged(m_domOwnerElement);
 }
 
 void KXEDeleteAttrCommand::unexecute()
 {
   m_domOwnerElement.setAttributeNode( m_domAttr );
-	m_pPart->updateNodeChanged( m_domOwnerElement ) ;
+	m_pDocument->updateNodeChanged( m_domOwnerElement ) ;
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////
@@ -318,10 +318,10 @@ void KXEDeleteAttrCommand::unexecute()
 //////////////////////////////////////////////////////////////////////////////////////////
 
 KXEDeleteAllAttribCommand::KXEDeleteAllAttribCommand(
-  KXMLEditorPart *pPart,
+  KXEDocument *pDocument,
   QDomElement &domOwnerElement
   )
- : KXECommand(pPart)
+ : KXECommand(pDocument)
 {
   m_domOwnerElement = domOwnerElement;
   m_listRemovedAttributes.setAutoDelete( true ); // the list owns the objects
@@ -354,7 +354,7 @@ void KXEDeleteAllAttribCommand::execute()
 			kdDebug() << "KXMLEditor " << k_funcinfo << " node is not an attribute (but should be)" << node.nodeName() << endl;
 	}
 
-  m_pPart->updateNodeChanged(m_domOwnerElement);
+  m_pDocument->updateNodeChanged(m_domOwnerElement);
 }
 
 void KXEDeleteAllAttribCommand::unexecute()
@@ -376,15 +376,15 @@ void KXEDeleteAllAttribCommand::unexecute()
 
   m_listRemovedAttributes.clear();
    
-  m_pPart->updateNodeChanged(m_domOwnerElement);
+  m_pDocument->updateNodeChanged(m_domOwnerElement);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////
 ///////////		Moving node up					//////////
 //////////////////////////////////////////////////////////////////////////////////////////
 
-KXEUpCommand::KXEUpCommand(KXMLEditorPart *pPart, QDomNode &domNode)
- : KXECommand(pPart)
+KXEUpCommand::KXEUpCommand(KXEDocument *pDocument, QDomNode &domNode)
+ : KXECommand(pDocument)
 {
   m_domNode = domNode;
   m_domParentNode = m_domNode.parentNode();
@@ -416,7 +416,7 @@ void KXEUpCommand::execute()
 			kdError() << "KXEUpCommand::execute can't insert child node." << endl;
 		else
 		{
-			m_pPart->updateNodeMoved(domNode);
+			m_pDocument->updateNodeMoved(domNode);
 		}
   }
 }
@@ -440,7 +440,7 @@ void KXEUpCommand::unexecute()
 			kdError() << "KXEUpCommand::unexecute can't insert child node." << endl;
 		else
 		{
-			m_pPart->updateNodeMoved(domNode);
+			m_pDocument->updateNodeMoved(domNode);
 		}
 	}
 }
@@ -449,8 +449,8 @@ void KXEUpCommand::unexecute()
 ///////////		Moving node down				//////////
 //////////////////////////////////////////////////////////////////////////////////////////
 
-KXEDownCommand::KXEDownCommand(KXMLEditorPart *pPart, QDomNode &domNode)
- : KXECommand(pPart)
+KXEDownCommand::KXEDownCommand(KXEDocument *pDocument, QDomNode &domNode)
+ : KXECommand(pDocument)
 {
   m_domNode = domNode;
   m_domParentNode = m_domNode.parentNode();
@@ -482,7 +482,7 @@ void KXEDownCommand::execute()
 			kdError() << "KXEDownCommand::execute can't insert child node." << endl;
 		else
 		{
-			m_pPart->updateNodeMoved(domNode);
+			m_pDocument->updateNodeMoved(domNode);
 		}
 	}
 }
@@ -506,7 +506,7 @@ void KXEDownCommand::unexecute()
 			kdError() << "KXEDownCommand::unexecute can't insert child node." << endl;
 		else
 		{
-			m_pPart->updateNodeMoved(domNode);
+			m_pDocument->updateNodeMoved(domNode);
 		}
   }
 }
@@ -516,11 +516,11 @@ void KXEDownCommand::unexecute()
 //////////////////////////////////////////////////////////////////////////////////////////
 
 KXEEditCharDataCommand::KXEEditCharDataCommand(
-  KXMLEditorPart *pPart,
+  KXEDocument *pDocument,
   QDomCharacterData &domCharacterData,
   const QString strNewContents
   )
- : KXECommand(pPart)
+ : KXECommand(pDocument)
 {
   m_domCharacterData = domCharacterData;
   m_strNewContents = strNewContents;
@@ -534,13 +534,13 @@ void KXEEditCharDataCommand::execute()
 {
   m_strOldContents = m_domCharacterData.data();
   m_domCharacterData.setData( m_strNewContents );
-  m_pPart->updateNodeChanged( m_domCharacterData );
+  m_pDocument->updateNodeChanged( m_domCharacterData );
 }
 
 void KXEEditCharDataCommand::unexecute()
 {
   m_domCharacterData.setData( m_strOldContents );
-  m_pPart->updateNodeChanged( m_domCharacterData );
+  m_pDocument->updateNodeChanged( m_domCharacterData );
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////
@@ -548,11 +548,11 @@ void KXEEditCharDataCommand::unexecute()
 //////////////////////////////////////////////////////////////////////////////////////////
 
 KXEEditProcInstrCommand::KXEEditProcInstrCommand(
-  KXMLEditorPart *pPart,
+  KXEDocument *pDocument,
   QDomProcessingInstruction &domProcInstr,
   const QString strNewData
   )
- : KXECommand(pPart)
+ : KXECommand(pDocument)
 {
   m_domProcInstr = domProcInstr;
   m_strNewData = strNewData;
@@ -566,13 +566,13 @@ void KXEEditProcInstrCommand::execute()
 {
   m_strOldData = m_domProcInstr.data();
   m_domProcInstr.setData( m_strNewData );
-  m_pPart->updateNodeChanged( m_domProcInstr );
+  m_pDocument->updateNodeChanged( m_domProcInstr );
 }
 
 void KXEEditProcInstrCommand::unexecute()
 {
   m_domProcInstr.setData( m_strOldData );
-  m_pPart->updateNodeChanged( m_domProcInstr );
+  m_pDocument->updateNodeChanged( m_domProcInstr );
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////
@@ -580,12 +580,12 @@ void KXEEditProcInstrCommand::unexecute()
 //////////////////////////////////////////////////////////////////////////////////////////
 
 KXEEditElementCommand::KXEEditElementCommand(
-  KXMLEditorPart *pPart,
+  KXEDocument *pDocument,
   QDomElement &domElement,
   const QString strNewPrefix,
   const QString strNewName
   )
- : KXECommand(pPart)
+ : KXECommand(pDocument)
 {
   m_domElement = domElement;
   m_strNewPrefix = strNewPrefix;
@@ -607,7 +607,7 @@ void KXEEditElementCommand::execute()
 
 	m_domElement.setTagName( m_strNewName );
   
-  m_pPart->updateNodeChanged( m_domElement );
+  m_pDocument->updateNodeChanged( m_domElement );
 }
 
 void KXEEditElementCommand::unexecute()
@@ -617,7 +617,7 @@ void KXEEditElementCommand::unexecute()
 
 	m_domElement.setTagName( m_strOldName );
   
-  m_pPart->updateNodeChanged( m_domElement );
+  m_pDocument->updateNodeChanged( m_domElement );
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////
@@ -626,11 +626,11 @@ void KXEEditElementCommand::unexecute()
 
 
 KXEEditAttrValueCommand::KXEEditAttrValueCommand(
-  KXMLEditorPart *pPart,
+  KXEDocument *pDocument,
   const QDomAttr &domAttr,
   const QString strNewValue
   )
- : KXECommand(pPart)
+ : KXECommand(pDocument)
 {
   m_domAttr = domAttr;
   m_strNewValue = strNewValue;
@@ -645,14 +645,14 @@ void KXEEditAttrValueCommand::execute()
   m_strOldValue = m_domAttr.value();
   m_domAttr.setValue( m_strNewValue );
   
-	m_pPart->updateNodeChanged(m_domAttr.ownerElement());
+	m_pDocument->updateNodeChanged(m_domAttr.ownerElement());
 }
 
 void KXEEditAttrValueCommand::unexecute()
 {
   m_domAttr.setValue( m_strOldValue );
   
-  m_pPart->updateNodeChanged(m_domAttr.ownerElement());
+  m_pDocument->updateNodeChanged(m_domAttr.ownerElement());
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////
@@ -661,11 +661,11 @@ void KXEEditAttrValueCommand::unexecute()
 
 
 KXEEditAttrNameCommand::KXEEditAttrNameCommand(
-  KXMLEditorPart *pPart,
+  KXEDocument *pDocument,
   const QDomAttr &domOldAttr,
   const QString strNewName
   )
- : KXECommand(pPart)
+ : KXECommand(pDocument)
 {
   m_strNewName = strNewName;
   m_strOldName = domOldAttr.name();
@@ -695,7 +695,7 @@ void KXEEditAttrNameCommand::execute()
     m_domOwnerElement.attributes().removeNamedItemNS (m_strNamespaceURI, m_strOldName);
   }
 
-  m_pPart->updateNodeChanged(m_domOwnerElement);
+  m_pDocument->updateNodeChanged(m_domOwnerElement);
 }
 
 void KXEEditAttrNameCommand::unexecute()
@@ -713,7 +713,7 @@ void KXEEditAttrNameCommand::unexecute()
     m_domOwnerElement.attributes().removeNamedItemNS (m_strNamespaceURI, m_strNewName);
   }
 
-  m_pPart->updateNodeChanged(m_domOwnerElement);
+  m_pDocument->updateNodeChanged(m_domOwnerElement);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////
@@ -721,11 +721,11 @@ void KXEEditAttrNameCommand::unexecute()
 //////////////////////////////////////////////////////////////////////////////////////////
 
 KXEEditRawXmlCommand::KXEEditRawXmlCommand(
-  KXMLEditorPart *pPart,
+  KXEDocument *pDocument,
   QDomElement &domOldElement,
   QDomElement &domNewElement
   )
- : KXECommand(pPart)
+ : KXECommand(pDocument)
 {
   m_domOldElement = domOldElement;
   m_domNewElement = domNewElement;
@@ -748,7 +748,7 @@ void KXEEditRawXmlCommand::execute()
 		kdError() << "KXEEditRawXmlCommand::execute error removing the selected node." << endl;
 	else
 	{
-		m_pPart->updateNodeDeleted(m_domOldElement);
+		m_pDocument->updateNodeDeleted(m_domOldElement);
   }
 
   // then insert new node
@@ -756,7 +756,7 @@ void KXEEditRawXmlCommand::execute()
 		m_domParentNode.insertBefore(m_domNewElement, m_afterNode);
 	else
   		m_domParentNode.insertAfter( m_domNewElement, m_afterNode );
-  	m_pPart->updateNodeCreated(m_domNewElement);
+  	m_pDocument->updateNodeCreated(m_domNewElement);
 }
 
 void KXEEditRawXmlCommand::unexecute()
@@ -766,7 +766,7 @@ void KXEEditRawXmlCommand::unexecute()
 		kdError() << "KXEEditRawXmlCommand::unexecute error removing the selected node." << endl;
 	else
 	{
-		m_pPart->updateNodeDeleted(m_domNewElement);
+		m_pDocument->updateNodeDeleted(m_domNewElement);
   }
 
   // then insert new node
@@ -774,5 +774,5 @@ void KXEEditRawXmlCommand::unexecute()
 		m_domParentNode.insertBefore(m_domOldElement, m_afterNode);
 	else
   		m_domParentNode.insertAfter( m_domOldElement, m_afterNode );
-  	m_pPart->updateNodeCreated(m_domOldElement);
+  	m_pDocument->updateNodeCreated(m_domOldElement);
 }
