@@ -20,7 +20,7 @@
 // KXMLEditorPartIfaceReadOnly
 //---------------------------------------------------------------------------
 QString
-KXMLEditorPartIfaceReadOnly::saveAsFile(const QString & path_to_file)
+KXMLEditorPartIfaceReadOnly::saveAsFile(const QString & )
 {
 	return "Not implemented.";
 }
@@ -50,7 +50,7 @@ QString
 KXMLEditorPartIfaceReadWrite::openURL(const QString  & szURL)
 {
 	KURL url(szURL);
-	if (! url.isValid () ) //Hope it is negation of bool isMalformed()
+	if (! url.isValid () )
 		return "URL is not valid.";
 	if ( m_pKXEPart->openURL(url) )
 		return QString();
