@@ -56,6 +56,7 @@ KXE_TreeView::KXE_TreeView( KXMLGUIClient * pGUIClient, QWidget * pParent, const
 	setSelectionMode(QListView::Single);
 
 	connect( this, SIGNAL(selectionChanged()), this, SLOT(slotSelectionChanged()) );
+	connect( this, SIGNAL(expanded(QListViewItem*)), this, SLOT(slotItemExpanded(QListViewItem*)) );
 
 	setReadWrite(false);
 
@@ -447,6 +448,14 @@ void KXE_TreeView::slotSelectionChanged()
 	}
 }
 
+
+void KXE_TreeView::slotItemExpanded( QListViewItem * pItem )
+{
+	KXE_TreeViewItem * pTreeViewItem = static_cast<KXE_TreeViewItem*> (pItem);
+	pTreeViewItem->ensureGrandChildItemsCreated();
+}
+
+
 //////////////////////////////////////////////////////////////
 // update slots
 //////////////////////////////////////////////////////////////
@@ -602,37 +611,45 @@ void KXE_TreeView::updateNodeMoved( const QDomNode & node )
 		return;
 	}
 
-	// Get the nodes parent node, to ...
-	QDomNode domParentNode = node.parentNode();
-	if ( domParentNode.isNull() )
+	// Now we can move the item (of the moved node). 
+	// We have to differenciate between the following 2 cases.
+	if ( node.previousSibling().isNull() )
 	{
-		kdError() << "KXE_TreeView::slotUpdateNodeMoved the node doesn't seem to have a parent node." << endl;
-		return;
-	}
-	// ... find the items new parent item. First try the old parent item (because it's very likely the correct one)
-	KXE_TreeViewItem * pNewParentItem = static_cast<KXE_TreeViewItem*> (pItem->parent());
-	if ( (!pNewParentItem) || ( *(pNewParentItem->xmlNode()) != domParentNode ) ) // no strike,
-		pNewParentItem = findCorrespondingItem(domParentNode);                    // do it the "long" way
+		// The node does not has a previous sibling. This means, it has been moved
+		// to be its parent first child. In this case, we have to find the tree
+		// view item of the node's next sibling to swap them.
+		// It's very likely the previous sibling of the item corresponding to the
+		// moved node.
+		KXE_TreeViewItem * pOldPrevItem = pItem->prevSibling();
+		   // Was it really?
+		if ( ! pOldPrevItem || ( *(pOldPrevItem->xmlNode()) != node.nextSibling() ) )
+			// It wasn't (how can it be?) - we have to find it using the "long" way.
+			pOldPrevItem = findCorrespondingItem( node.nextSibling() );
 
-	if ( ! pNewParentItem ) // can't find the corresponding new parent item
-	{
-		kdError() << "KXE_TreeView::slotUpdateNodeMoved can't find the new parent item to the given nodes parent node." << endl;
-		return;
+		if ( ! pOldPrevItem ) // something went wrong
+		{
+			kdError() << "KXE_TreeView::slotUpdateNodeMoved can't find the item to the given node's next sibling." << endl;
+			return;
+		}
+
+		// Now we can swap them (make the old previous item the new next item of 
+		// the moved node's item).
+		pOldPrevItem->moveItem( pItem );
 	}
-		
-	// Now find the nodes prev.sibling to get the items new prev.sibling.
-	QDomNode domPrevSibling = node.previousSibling();
-	if ( domPrevSibling.isNull() )
-		moveItem( pItem, pNewParentItem, 0 ); // no prev.sibl. -> make it the first child
 	else
-	{                            // find the new prev.sibling item
-		KXE_TreeViewItem * pNewPrevItem = findCorrespondingItem(domPrevSibling);
-		if (!pNewPrevItem)
+	{
+		// The node has a previous sibling. In this case we have to find the 
+		// corresponding tree view item to swap it with the item corresponding to
+		// the moved node.
+		KXE_TreeViewItem * pNewPrevItem = findCorrespondingItem( node.previousSibling() );
+		if ( ! pNewPrevItem )
 		{
 			kdError() << "KXE_TreeView::slotUpdateNodeMoved can't find the new prev.item to the given nodes prev.node." << endl;
 			return;
 		}
-		moveItem( pItem, pNewParentItem, pNewPrevItem );
+
+		// swap them (move the moved node's item after the previous sibling's item)
+		pItem->moveItem( pNewPrevItem );
 	}
 
 	setSelected( pItem, true );
@@ -822,13 +839,13 @@ bool KXE_TreeView::drop(QListViewItem *pItem, QDropEvent *pDropEvent)
 				
 			if(m_pCurrentBeforeDropItem && pTreeItem &&
 				  static_cast <KXE_TreeViewItem*> (m_pCurrentBeforeDropItem)->isMyChildren(pTreeItem))
-				{	KMessageBox::sorry(0, i18n("Item cannot be moved into their child subtree !"));
+				{	KMessageBox::sorry(0, i18n("An XML element can't be moved to its own subtree."));
 					return false;
 				}
 
       if (pTreeItem->xmlNode()->isProcessingInstruction())
 			{
-        KMessageBox::sorry(0, i18n("Item cannot be moved to processing instruction !"));
+        KMessageBox::sorry(0, i18n("An XML node can't be moved in a processing instruction."));
 				return false;
       }
 
