@@ -189,6 +189,16 @@ protected:
 protected slots:
 	/** Checks, which type of item was selected an emits the corresponding signal. */
 	void slotSelectionChanged();
+	/**
+	 * Ensures that the expanded item's grandchild items are created.
+	 * This is very important for the "create items on demand" mode. But even in
+	 * "create all items while loading" mode, this function has to be executed,
+	 * because KXMLEditor could have been in "create items on demand" mode during
+	 * the opening of the document.
+	 *
+	 * To be connected to the signal QListView::expanded(QListViewItem*).
+	 */
+	void slotItemExpanded( QListViewItem * );
 
 private slots:
 
