@@ -24,10 +24,12 @@
 #include "kxetextviewsettings.h"
 
 #include <kconfig.h>
+#include <ktextedit.h>
 
-#include <qmultilineedit.h>
 #include <qdom.h>
 #include <qcolor.h>
+#include <qpalette.h>
+
 
 #include "qdom_add.h"
 
@@ -44,18 +46,20 @@ KXE_ViewElement::KXE_ViewElement( QWidget * pParent, KConfig *pConfig, const cha
   connect( m_pViewAttributes, SIGNAL(sigAttributeNameChangedInplace(const QDomAttr&, const QString)), this, SIGNAL(sigAttributeNameChangedInplace(const QDomAttr&, const QString)) );
   connect( m_pViewAttributes, SIGNAL(sigAttributeValueChangedInplace(const QDomAttr&, const QString)), this, SIGNAL(sigAttributeValueChangedInplace(const QDomAttr&, const QString)) );
 
-	m_pViewPlainXML = new QMultiLineEdit( this, "plain XML" );
+	m_pViewPlainXML = new KTextEdit( this, "plain XML" );
 	m_pViewPlainXML->setReadOnly(true);
+	m_pViewPlainXML->setTextFormat(KTextEdit::PlainText);
+	m_pViewPlainXML->setPaletteBackgroundColor(pParent->palette().active().base()); // Owerwrite read-only background color
   m_pViewPlainXML->setWordWrap( QTextEdit::NoWrap );
   m_pSyntaxHighlighter = new KXESyntaxHighlighter(m_pViewPlainXML);
 
-  	// configuring spliiter sizes
+  	// configuring splitter sizes
 	if (m_pConfig)
 	{
 		QValueList<int> list = m_pConfig->readIntListEntry(CONFIG_SPLITTER_SIZES);
 		if (!list.isEmpty())
 			setSizes(list);
-        }
+  }
 
 	// Apply current configuration
 	slotTextViewSettingsChanged();
@@ -107,5 +111,16 @@ void KXE_ViewElement::slotTextViewSettingsChanged()
 	m_pSyntaxHighlighter->setColorComments( KXMLEditorFactory::configuration()->textview()->colorComments() );
 	m_pSyntaxHighlighter->setColorSyntaxError( KXMLEditorFactory::configuration()->textview()->colorErrors() );
 
+	if(KXMLEditorFactory::configuration()->textview()->isWrapOn())
+	{
+		m_pViewPlainXML->setHScrollBarMode(QScrollView::AlwaysOff);
+		m_pViewPlainXML->setWordWrap(QTextEdit::WidgetWidth);
+	}
+	else
+	{
+		m_pViewPlainXML->setHScrollBarMode(QScrollView::Auto);
+		m_pViewPlainXML->setWordWrap(QTextEdit::NoWrap);
+	}
+	
 	m_pSyntaxHighlighter->rehighlight();
 }
