@@ -24,7 +24,7 @@
 
 // forward declarations
 class KXE_ViewAttributes;
-class QMultiLineEdit;
+class KTextEdit;
 class KConfig;
 class KXESyntaxHighlighter;
 
@@ -33,7 +33,7 @@ class KXESyntaxHighlighter;
  * This widget shows a table of XML elements attributes
  * and plain XML text of this element and its children.
  *
- * @short widget for XML elements
+ * @short Widget for XML elements.
  */
 class KXE_ViewElement : public QSplitter
 {
@@ -42,7 +42,7 @@ class KXE_ViewElement : public QSplitter
 	public:
 
 		KXE_ViewElement( QWidget * pParent, KConfig *pConfig, const char * pszName = 0 );
-    ~KXE_ViewElement();
+		~KXE_ViewElement();
 
 		/** Returns a pointer to the currently selected attribute or a null pointer. */
 		QDomAttr getSelectedAttribute() const;
@@ -65,13 +65,13 @@ class KXE_ViewElement : public QSplitter
 		/** table widget to display XML attributes */
 		KXE_ViewAttributes * m_pViewAttributes;
 		/** edit widget for plain XML */
-		QMultiLineEdit * m_pViewPlainXML;
+		KTextEdit * m_pViewPlainXML;
 
 		/** configuration used to store splitter sizes */
 		KConfig *m_pConfig;
 
-    /** Syntax highlighter for m_pViewPlainXML */
-    KXESyntaxHighlighter *m_pSyntaxHighlighter;
+		/** Syntax highlighter for m_pViewPlainXML */
+		KXESyntaxHighlighter *m_pSyntaxHighlighter;
 
 	signals:
 
