@@ -41,10 +41,9 @@ class KXMLEditorAboutData : public KAboutData
 		               "http://kxmleditor.sourceforge.net",
 		               "lvanek@users.sourceforge.net" )
 		{
-			addAuthor("Lumir Vanek", I18N_NOOP("Developer and maintainer"), "lvanek@users.sourceforge.net");
+			addAuthor("Lumir Vanek", I18N_NOOP("Developer and maintainer"), "lvanek@users.sourceforge.net", "http://www.valachnet.cz/lvanek");
 			addAuthor("Olaf Hartig", I18N_NOOP("Developer"), "hartig@users.sourceforge.net");
-			//addAuthor("Mateusz Korniak", I18N_NOOP("DCOP code"), "matkor@users.sourceforge.net");
-      addAuthor("Adam Charytoniuk", I18N_NOOP("Developer"), "a_charytoniuk@users.sourceforge.net");
+			addAuthor("Adam Charytoniuk", I18N_NOOP("Developer"), "a_charytoniuk@users.sourceforge.net");
     }
 };
 
