@@ -19,6 +19,7 @@
 #include "kxmleditorpart.h"
 #include "kxmleditorabout.h"
 #include "kxeconfiguration.h"
+#include "kxedocument.h"
 
 #include <kinstance.h>
 #include <kdebug.h>
@@ -29,7 +30,7 @@ extern "C"
 	{
 		return new KXMLEditorFactory;
 	}
-};
+} 
 
 KInstance * KXMLEditorFactory::s_instance = 0L;
 KXEConfiguration * KXMLEditorFactory::s_pKXEConfig = 0L;
@@ -52,22 +53,25 @@ KXMLEditorFactory::~KXMLEditorFactory()
 	s_instance = 0L;
 }
 
-KParts::Part * KXMLEditorFactory::createPartObject( QWidget * pParentWidget, const char * pszWidgetName, QObject * pParent, const char * pszName, const char * pszClassName, const QStringList & args )
+KParts::Part * KXMLEditorFactory::createPartObject( QWidget * pParentWidget, const char * pszWidgetName, QObject * pParent, const char * pszName, const char * pszClassName, const QStringList & )
 {
 	// eliminating compiler warnings
 	pParent = pParent;
 	pszName = pszName;
 
-	KXMLEditorPart * pPart;
+	KParts::Part * pPart=0L;
+	KXEDocument* pDocument=0L;
 	if ( QCString(pszClassName) == "KParts::ReadOnlyPart" )
 	{
-		pPart = new KXMLEditorPart( false, pParentWidget, pszWidgetName );
+		pDocument = new KXEDocument();
+		pPart = new KXMLEditorPart( false, pDocument, pParentWidget, pszWidgetName );
 		kdDebug() << "KXMLEditorFactory::createPartObject: read only KXMLEditorPart created" << endl;
 	}
 	else if ( (QCString(pszClassName) == "KParts::ReadWritePart") ||
 	          (QCString(pszClassName) == "KXMLEditorPart") )
 	{
-		pPart = new KXMLEditorPart( true, pParentWidget, pszWidgetName );
+		pDocument = new KXEDocument();
+		pPart = new KXMLEditorPart( true, pDocument, pParentWidget, pszWidgetName );
 		kdDebug() << "KXMLEditorFactory::createPartObject: read/write KXMLEditorPart created" << endl;
 	}
 	else
@@ -76,6 +80,7 @@ KParts::Part * KXMLEditorFactory::createPartObject( QWidget * pParentWidget, con
 		return 0L;
 	}
 
+
 	emit objectCreated( pPart );
 
 	return pPart;
