@@ -15,6 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
+ /**
+@file
+*/
+
 #ifndef KXMLEDITORFACTORY_H
 #define KXMLEDITORFACTORY_H
 
@@ -22,15 +26,20 @@
 
 class KInstance;
 class KXEConfiguration;
-
+/**
+	@brief Factory for creating our parts.
+*/
 class KXMLEditorFactory : public KParts::Factory
 {
 		Q_OBJECT
 
 	public:
+		/** @brief Constructor  */
 		KXMLEditorFactory( QObject * pParent = 0, const char * pszName = 0 );
+		/** @brief Destructor  */
 		virtual ~KXMLEditorFactory();
 
+		/** @short Creates part object, depending on given part class */
 		virtual KParts::Part * createPartObject( QWidget * pParentWidget = 0, const char * pszWidgetName = 0, QObject * pParent = 0, const char * pszName = 0, const char * pszClassName = "KParts::Part", const QStringList & args = QStringList() );
 
 		static KInstance * instance();
@@ -39,7 +48,7 @@ class KXMLEditorFactory : public KParts::Factory
 	private:
 		static KInstance * s_instance;
 
-		/** our configuration - the same for all parts */
+		/** @brief Our configuration - the same for all parts. */
 		static KXEConfiguration * s_pKXEConfig;
 };
 
