@@ -237,7 +237,7 @@ KXMLEditorPart::KXMLEditorPart( bool fReadWrite, KXEDocument* pDocument, QWidget
 	//////////////////////////////
 
 	pSplitter = new QSplitter( pParent, "KXMLEditorPart main widget (Splitter)" );
-	pSplitter->setFocusPolicy( QWidget::StrongFocus );
+	pSplitter->setFocusPolicy( QWidget::NoFocus );
 	pSplitter->setOpaqueResize(true);
 	setWidget( pSplitter );
 
@@ -254,6 +254,7 @@ KXMLEditorPart::KXMLEditorPart( bool fReadWrite, KXEDocument* pDocument, QWidget
 
 	// create tab widget ----------------------
 	m_pTabWidget = new QTabWidget( pSplitter, "KXMLEditorPart tabwidget");
+	m_pTabWidget->setFocusPolicy( QWidget::NoFocus );
 
 	// create element view
 	m_pViewElement = new KXE_ViewElement( m_pTabWidget, instance()->config(), "KXMLEditorPart element view" );
